[CHNOSZ-commits] r444 - in pkg/CHNOSZ: . demo inst inst/extdata/cpetc man

noreply at r-forge.r-project.org noreply at r-forge.r-project.org
Mon Apr 15 16:00:52 CEST 2019


Author: jedick
Date: 2019-04-15 16:00:52 +0200 (Mon, 15 Apr 2019)
New Revision: 444

Added:
   pkg/CHNOSZ/inst/extdata/cpetc/Mer75_Table4.csv
   pkg/CHNOSZ/inst/extdata/cpetc/TKSS14_Fig2.csv
Modified:
   pkg/CHNOSZ/DESCRIPTION
   pkg/CHNOSZ/demo/00Index
   pkg/CHNOSZ/demo/go-IU.R
   pkg/CHNOSZ/inst/NEWS
   pkg/CHNOSZ/man/examples.Rd
   pkg/CHNOSZ/man/extdata.Rd
Log:
demo/go-IU.R: add plots from Tutolo et al., 2014


Modified: pkg/CHNOSZ/DESCRIPTION
===================================================================
--- pkg/CHNOSZ/DESCRIPTION	2019-04-15 09:20:57 UTC (rev 443)
+++ pkg/CHNOSZ/DESCRIPTION	2019-04-15 14:00:52 UTC (rev 444)
@@ -1,6 +1,6 @@
 Date: 2019-04-15
 Package: CHNOSZ
-Version: 1.3.1-24
+Version: 1.3.1-25
 Title: Thermodynamic Calculations and Diagrams for Geochemistry
 Authors at R: c(
     person("Jeffrey", "Dick", , "j3ffdick at gmail.com", role = c("aut", "cre"),

Modified: pkg/CHNOSZ/demo/00Index
===================================================================
--- pkg/CHNOSZ/demo/00Index	2019-04-15 09:20:57 UTC (rev 443)
+++ pkg/CHNOSZ/demo/00Index	2019-04-15 14:00:52 UTC (rev 444)
@@ -16,7 +16,7 @@
 arsenic         Another example of mosaic(): Eh-pH diagram for the system As-O-H-S
 solubility      Solubility of calcite and CO2(gas) as a function of pH
 gold            Solubility of gold
-contour         Gold solubility contours on log fO2 - pH diagram
+contour         Gold solubility contours on a log fO2 - pH diagram
 wjd             Gibbs energy minimization: prebiological atmospheres and cell periphery of yeast
 dehydration     log K of dehydration reactions; SVG file contains tooltips and links
 bugstab         Formation potential of microbial proteins in colorectal cancer
@@ -26,7 +26,7 @@
 DEW             Deep Earth Water (DEW) model for high pressures
 lambda          Thermodynamic properties of lambda transition in quartz
 TCA             Standard Gibbs energies of steps of the citric acid cycle
-go-IU           Diagrams using thermodynamic data in the SUPCRTBL compilation
+go-IU           Reactions involving Al-bearing minerals
 carboxylase     Rank abundance distribution for RuBisCO and acetyl-CoA carboxylase
 bison           Average oxidation state of carbon in proteins for phyla at Bison Pool
 AkDi            Henry's constant of dissolved gases

Modified: pkg/CHNOSZ/demo/go-IU.R
===================================================================
--- pkg/CHNOSZ/inst/NEWS	2019-04-15 09:20:57 UTC (rev 443)
+++ pkg/CHNOSZ/inst/NEWS	2019-04-15 14:00:52 UTC (rev 444)
@@ -1,4 +1,4 @@
-CHANGES IN CHNOSZ 1.3.1-24 (2019-04-15)
+CHANGES IN CHNOSZ 1.3.1-25 (2019-04-15)
 ---------------------------------------
 
 - Add thermo/stoich.csv.xz (loaded as thermo()$stoich), containing a
@@ -40,6 +40,8 @@
 
 - Add demo/arsenic.R (Eh-pH diagram after Lu and Zhu, 2011).
 
+- demo/go-IU.R: add plots from Tutolo et al., 2014.
+
 CHANGES IN CHNOSZ 1.3.1 (2019-03-02)
 ------------------------------------
 

Added: pkg/CHNOSZ/inst/extdata/cpetc/Mer75_Table4.csv
===================================================================
--- pkg/CHNOSZ/inst/extdata/cpetc/Mer75_Table4.csv	                        (rev 0)
+++ pkg/CHNOSZ/inst/extdata/cpetc/Mer75_Table4.csv	2019-04-15 14:00:52 UTC (rev 444)
@@ -0,0 +1,42 @@
+Brine,log(aNa+/aH+),log(aK+/aH+)
+1,7.38,5.515
+2,7.209,5.362
+3,7.094,5.286
+5,7.121,5.263
+8,7.868,5.797
+9,7.997,5.971
+11,8.02,5.97
+12,8.05,5.98
+13,7.568,5.55
+16,7.611,5.581
+17,7.66,5.626
+19,8,6.01
+20,7.99,5.99
+24,7.584,5.544
+25,7.52,5.39
+26,6.856,5.033
+28,7.9,5.93
+29,7.594,5.515
+30,7.294,5.723
+31,7.719,5.643
+41,7.299,5.22
+45,7.457,5.455
+52,8.25,6.17
+53,8.114,6.08
+58,7.805,5.752
+59,784,5.69
+63,7.245,5.451
+65,7.435,5.375
+66,7.94,5.74
+69,7.775,5.62
+70,7.96,5.77
+72,8.399,5.961
+73,8.242,6.009
+74,7.73,5.55
+78,8.233,6.069
+80,8.25,6.09
+83,7.554,3.7325
+88,6.896,4.805
+97,8.224,6.116
+99,8.18,6.05
+100,7.597,5.503

Added: pkg/CHNOSZ/inst/extdata/cpetc/TKSS14_Fig2.csv
===================================================================
--- pkg/CHNOSZ/inst/extdata/cpetc/TKSS14_Fig2.csv	                        (rev 0)
+++ pkg/CHNOSZ/inst/extdata/cpetc/TKSS14_Fig2.csv	2019-04-15 14:00:52 UTC (rev 444)
@@ -0,0 +1,25 @@
+x,y
+3.353,11.57
+3.353,11.2
+3.353,8.83
+3.351,9.9
+3.353,9.22
+3.351,10.79
+2.113,5.97
+1.909,4.3
+1.859,3.82
+1.746,2.84
+3.351,11.05
+2.829,6.87
+2.113,5.39
+2.113,4.5
+1.744,2.76
+1.744,-0.15
+2.113,5.28
+1.824,3.54
+3.001,10.39
+2.752,9.39
+2.609,9.02
+2.363,6.85
+2.363,6.35
+3.388,10.61

Modified: pkg/CHNOSZ/man/examples.Rd
===================================================================
--- pkg/CHNOSZ/man/examples.Rd	2019-04-15 09:20:57 UTC (rev 443)
+++ pkg/CHNOSZ/man/examples.Rd	2019-04-15 14:00:52 UTC (rev 444)
@@ -49,7 +49,7 @@
     \code{arsenic} \tab Another example of \code{\link{mosaic}}: Eh-pH diagram for the system As-O-H-S (Lu and Zhu, 2011) \cr
     \code{solubility} \tab Solubility of calcite (cf. Manning et al., 2013) and \CO2 (cf. Stumm and Morgan, 1996) \cr
     \code{gold} \tab Solubility of gold (Akinfiev and Zotov; 2001; Stef{\aacute}nsson and Seward, 2004; Williams-Jones et al., 2009) \cr
-    \code{contour} \tab Gold solubility contours on log fO2 - pH diagram (Williams-Jones et al., 2009) \cr
+    \code{contour} \tab Gold solubility contours on a log fO2 - pH diagram (Williams-Jones et al., 2009) \cr
     \code{wjd} \tab \eqn{G}{G} minimization: prebiological atmospheres (Dayhoff et al., 1964) and cell periphery of yeast \cr
     \code{dehydration} \tab \logK of dehydration reactions; SVG file contains tooltips and links \cr
     \code{bugstab} \tab Formation potential of microbial proteins in colorectal cancer (Dick, 2016) \cr
@@ -59,7 +59,7 @@
     \code{DEW} \tab Deep Earth Water (DEW) model for high pressures (Sverjensky et al., 2014a and 2014b) \cr
     \code{lambda} \tab Effects of lambda transition on thermodynamic properties of quartz (Berman, 1988) \cr
     \code{TCA} \tab Standard Gibbs energies of the tricarboxylic (citric) acid cycle (Canovas and Shock, 2016) \cr
-    \code{go-IU} \tab Diagrams using thermodynamic data in the SUPCRTBL compilation (Zimmer et al., 2016) \cr
+    \code{go-IU} \tab Reactions involving Al-bearing minerals (Zimmer et al., 2016; Tutolo et al., 2014) \cr
     \code{carboxylase} \tab Rank abundance distribution for RuBisCO and acetyl-CoA carboxylase \cr
     \code{bison} \tab Average oxidation state of carbon in proteins for phyla at Bison Pool (Dick and Shock, 2013) \cr
     \code{AkDi} \tab Henry's constant of dissolved gases (Akinfiev and Diamond, 2003) \cr
@@ -142,6 +142,8 @@
 
 Sverjensky, D. A., Stagno, V. and Huang, F. (2014b) Important role for organic carbon in subduction-zone fluids in the deep carbon cycle. \emph{Nat. Geosci.} \bold{7}, 909--913. \url{https://doi.org/10.1038/ngeo2291}
 
+Tutolo, B. M., Kong, X.-Z., Seyfried, W. E., Jr. and Saar, M. O. (2014) Internal consistency in aqueous geochemical data revisited: Applications to the aluminum system. \emph{Geochim. Cosmochim. Acta} \bold{133}, 216--234. \url{https://doi.org/10.1016/j.gca.2014.02.036}
+
 Williams-Jones, A. E., Bowell, R. J. and Migdisov, A. A. (2009) Gold in solution. \emph{Elements} \bold{5}, 281--287. \url{https://doi.org/10.2113/gselements.5.5.281}
 
 Zimmer, K., Zhang, Y., Lu, P., Chen, Y., Zhang, G., Dalkilic, M. and Zhu, C. (2016) SUPCRTBL: A revised and extended thermodynamic dataset and software package of SUPCRT92. \emph{Comp. Geosci.} \bold{90}, 97--111. \url{https://doi.org/10.1016/j.cageo.2016.02.013}

Modified: pkg/CHNOSZ/man/extdata.Rd
===================================================================
--- pkg/CHNOSZ/man/extdata.Rd	2019-04-15 09:20:57 UTC (rev 443)
+++ pkg/CHNOSZ/man/extdata.Rd	2019-04-15 14:00:52 UTC (rev 444)
@@ -48,6 +48,8 @@
     \item \code{rubisco.csv} UniProt IDs for Rubisco, ranges of optimal growth temperature of organisms, domain and name of organisms, and URL of reference for growth temperature, from Dick, 2014. See the vignette \code{anintro.Rmd} for an example that uses this file.
     \item \code{bluered.txt} Blue - light grey - red color palette, computed using \CRANpkg{colorspace}\code{::diverge_hcl(1000,} \code{c = 100, l = c(50, 90), power = 1)}. This is used by \code{\link{ZC.col}}.
     \item \code{AD03_Fig1?.csv} Experimental data points digitized from Figure 1 of Akinfiev and Diamond, 2003, used in \code{\link{demos}("AkDi")}.
+    \item \code{TKSS14_Fig2.csv} Experimental data points digitized from Figure 2 of Tutolo et al., 2014, used in \code{\link{demos}("go-IU")}.
+    \item \code{Mer75_Table4.csv} Values of log(aK+/aH+) and log(aNa+/aH+) from Table 4 of Merino, 1975, used in \code{\link{demos}("go-IU")}.
   }
 
   Files in \code{fasta} contain protein sequences:
@@ -151,6 +153,8 @@
 
 Joint Genome Institute (2007) Bison Pool Environmental Genome. Protein sequence files downloaded from IMG/M (\url{http://img.jgi.doe.gov/cgi-bin/m/main.cgi?section=FindGenomes&page=findGenomes})
 
+Merino, E. (1975) Diagenesis in teriary sandstones from Kettleman North Dome, California. II. Interstitial solutions: distribution of aqueous species at 100°C and chemical relation to diagenetic mineralogy. \emph{Geochim. Cosmochim. Acta} \bold{39}, 1629--1645. \url{https://doi.org/10.1016/0016-7037(75)90085-X}
+
 Privalov, P. L. and Makhatadze, G. I. (1990) Heat capacity of proteins. II. Partial molar heat capacity of the unfolded polypeptide chain of proteins: Protein unfolding effects. \emph{J. Mol. Biol.} \bold{213}, 385--391. \url{https://doi.org/10.1016/S0022-2836(05)80198-6}
 
 Richard, L. and Helgeson, H. C. (1998) Calculation of the thermodynamic properties at elevated temperatures and pressures of saturated and aromatic high molecular weight solid and liquid hydrocarbons in kerogen, bitumen, petroleum, and other organic matter of biogeochemical interest. \emph{Geochim. Cosmochim. Acta} \bold{62}, 3591--3636. \url{https://doi.org/10.1016/S0016-7037(97)00345-1}
@@ -171,6 +175,8 @@
 
 Tai, S. L., Boer, V. M., Daran-Lapujade, P., Walsh, M. C., de Winde, J. H., Daran, J.-M. and Pronk, J. T. (2005) Two-dimensional transcriptome analysis in chemostat cultures: Combinatorial effects of oxygen availability and macronutrient limitation in \emph{Saccharomyces cerevisiae}. \emph{J. Biol. Chem.} \bold{280}, 437--447. \url{https://doi.org/10.1074/jbc.M410573200}
 
+Tutolo, B. M., Kong, X.-Z., Seyfried, W. E., Jr. and Saar, M. O. (2014) Internal consistency in aqueous geochemical data revisited: Applications to the aluminum system. \emph{Geochim. Cosmochim. Acta} \bold{133}, 216--234. \url{https://doi.org/10.1016/j.gca.2014.02.036}
+
 YeastGFP project. Yeast GFP Fusion Localization Database, http://yeastgfp.ucsf.edu; Current location: \url{http://yeastgfp.yeastgenome.org}
 }
 



More information about the CHNOSZ-commits mailing list
--- pkg/CHNOSZ/demo/go-IU.R	2019-04-15 09:20:57 UTC (rev 443)
+++ pkg/CHNOSZ/demo/go-IU.R	2019-04-15 14:00:52 UTC (rev 444)
@@ -1,48 +1,50 @@
 # CHNOSZ/demo/go-IU.R  20171018
 # diagrams using data from the SUPCRTBL compilation
 # (BL = Bloomington campus of Indiana University)
 
 ## set up plotting area
-opar <- par(mfrow=c(2, 2))
+opar <- par(mfrow = c(2, 2))
 
 ###########
 ### plot 1: boehmite - kaolinite equilibrium
 ###########
-## experimental data from Table 1 of Hemley et al., 1980
-# doi:10.2113/gsecongeo.75.2.210
+# After Zhu and Lu, 2009 (doi:10.1016/j.gca.2009.03.015)
+# experimental data from Table 1 of Hemley et al., 1980 (doi:10.2113/gsecongeo.75.2.210)
 xT <- c(200, 200, 200, 200, 250, 250, 265, 300, 300, 300, 300)
 xlogaSiO2 <- -c(2.54, 2.59, 2.65, 2.77, 2.21, 2.32, 2.12, 1.90, 1.95, 1.94, 1.90)
 ## set up basis species so that axis.label shows activity of SiO2
 basis(c("Al2O3","SiO2", "H2O", "O2"))
 T <- 125:350
-thermo.plot.new(xlim=range(T), ylim=c(-3.5, -1.5), xlab = axis.label("T"), ylab=axis.label("SiO2"))
+thermo.plot.new(xlim = range(T), ylim = c(-3.5, -1.5), xlab = axis.label("T"), ylab = axis.label("SiO2"))
 points(xT, xlogaSiO2)
-basis(delete=TRUE)
+basis(delete = TRUE)
 ## first calculation: as in SUPCRT92
 add.obigt("SUPCRT92") # gets kaolinite and boehmite from HDNB78
-r1 <- subcrt(c("boehmite", "H2O", "SiO2", "kaolinite"), c(-1, -0.5, -1, 0.5), T=T, P=1000, exceed.Ttr = TRUE) 
+r1 <- subcrt(c("boehmite", "H2O", "SiO2", "kaolinite"), c(-1, -0.5, -1, 0.5), T = T, P = 1000, exceed.Ttr = TRUE) 
 # we need exceed.Ttr = TRUE because the T limit for boehmite is 500 K (Helgeson et al., 1978)
 ## second calculation: CHNOSZ default
 # kaolinite from Berman, 1988
 # boehmite from Hemingway et al., 1991
 # SiO2 from Apps and Spycher, 2004
 reset()
-r2 <- subcrt(c("boehmite", "H2O", "SiO2", "kaolinite"), c(-1, -0.5, -1, 0.5), T=T, P=1000, exceed.Ttr = TRUE) 
+r2 <- subcrt(c("boehmite", "H2O", "SiO2", "kaolinite"), c(-1, -0.5, -1, 0.5), T = T, P = 1000, exceed.Ttr = TRUE) 
 ## third calculation: get SiO2(aq) from SHS89
 add.obigt("AS04")
-r3 <- subcrt(c("boehmite", "H2O", "SiO2", "kaolinite"), c(-1, -0.5, -1, 0.5), T=T, P=1000, exceed.Ttr = TRUE) 
+r3 <- subcrt(c("boehmite", "H2O", "SiO2", "kaolinite"), c(-1, -0.5, -1, 0.5), T = T, P = 1000, exceed.Ttr = TRUE) 
 ## log activity of SiO2 is -ve logK
-lines(T, -r1$out$logK)
-lines(T, -r2$out$logK, col="red")
-lines(T, -r3$out$logK, col="red", lty = 2)
+lines(T, -r1$out$logK, col = "blue1", lty = 2)
+lines(T, -r2$out$logK, lwd = 1.5)
+lines(T, -r3$out$logK, col = "red", lty = 2)
 ## add points calculated using the SUPCRTBL package
-points(seq(125, 350, 25), -c(3.489, 3.217, 2.967, 2.734, 2.517, 2.314, 2.124, 1.946, 1.781, 1.628), pch=4, col="red")
+points(seq(125, 350, 25), -c(3.489, 3.217, 2.967, 2.734, 2.517, 2.314, 2.124, 1.946, 1.781, 1.628), pch = 4, col = "red")
 ## add legend and title
-legend("bottomright", lty=c(0, 0, 1, 1, 2), pch=c(1, 4, NA, NA, NA),
-       col=c("black", "red", "black", "red", "red"), bty="n", cex=0.9,
-       legend=c("Hemley et al., 1980", "SUPCRTBL", "SUPCRT92", "CHNOSZ (default)", 'add.obigt("AS04")'))
-mtitle(c("Kaolinite - Boehmite", "After Zhu and Lu, 2009 Fig. A1"), cex=0.95)
-# Zhu and Lu, 2009: doi:10.1016/j.gca.2009.03.015
+title(main = describe.reaction(r1$reaction), cex.main = 1.1)
+legend("bottomright", lty = c(0, 0, 2, 1, 2), pch = c(1, 4, NA, NA, NA), lwd = c(1, 1, 1, 1.5, 1),
+       col = c("black", "red", "black", "black", "red"), bty = "n", cex = 0.9,
+       legend = c("Hemley et al., 1980", "SUPCRTBL", "SUPCRT92", "CHNOSZ", 'add.obigt("AS04")'))
+legend("topleft", c("Boehmite - Kaolinite", "After Zhu and Lu, 2009 Fig. A1"), bty = "n")
+reset()
 # Helgeson et al., 1978 (HDNB78): http://www.worldcat.org/oclc/13594862
 # Shock et al., 1989 (SHS89): doi:10.1016/0016-7037(89)90341-4
 # Berman, 1988 (Ber88): doi:10.1093/petrology/29.2.445
@@ -53,34 +55,84 @@
 ###########
 ### plot 2: dawsonite solubility
 ###########
 ## experimental data from Benezeth et al., 2007 Table 5
 # doi:10.1016/j.gca.2007.07.003
 # (averages for each temperature in a single run)
 T <- c(100.1, 100.1, 150.1, 100.1, 150.1, 99.8, 99.8, 200.7, 99.8, 50.1, 75.1, 100.3, 150.1)
 logK <- -c(14.825, 14.735, 13.625, 14.79, 13.665, 14.725, 14.1775, 12.74, 14.4925, 16.8625, 15.61, 14.51, 13.455)
-plot(T, logK, xlim=c(25, 250), ylim=c(-18, -10), xlab=axis.label("T"), ylab=axis.label("logK"))
+plot(T, logK, xlim = c(25, 250), ylim = c(-18, -10), xlab = axis.label("T"), ylab = axis.label("logK"))
 T <- 0:250
 # calculation 1: CHNOSZ default
 species <- c("dawsonite", "H2O", "Al(OH)4-", "HCO3-", "Na+", "H+")
 coeffs <- c(-1, -2, 1, 1, 1, 1)
-Daw1 <- subcrt(species, coeffs, T=T)
+Daw1 <- subcrt(species, coeffs, T = T)
 # calculation 2: dawsonite with Cp = 0
-mod.obigt("dawsonite", Cp=0)
-Daw2 <- subcrt(species, coeffs, T=T)
+mod.obigt("dawsonite", Cp = 0)
+Daw2 <- subcrt(species, coeffs, T = T)
 ## plot the calculated logKs
-lines(T, Daw1$out$logK, col="red")
-lines(T, Daw2$out$logK, col="red", lty=2)
+lines(T, Daw1$out$logK, lwd = 1.5)
+lines(T, Daw2$out$logK, col = "red", lty = 2)
 ## add points calculated using the SUPCRTBL package
 points(seq(25, 250, 25), c(-17.829, -16.523, -15.402, -14.425, -13.568, -12.815, -12.154, -11.581, -11.094, -10.699), pch=4, col="red")
 ## add legend and title
-legend("bottomright", lty=c(0, 0, 1, 2), pch=c(1, 4, NA, NA), col=c("black", "red", "red", "red"),
-       bty="n", cex=0.9, legend=c("Ben\u00e9z\u00e9th et al., 2007", "SUPCRTBL", "CHNOSZ", 'mod.obigt("dawsonite", Cp = 0)'))
-mtitle(c("Dawsonite - aqueous species", "After Zimmer et al., 2016 Fig. 2"), cex=0.95)
-# doi:10.1016/j.cageo.2016.02.013
+title(main = describe.reaction(Daw1$reaction), cex.main = 0.95)
+legend("bottomright", lty = c(0, 0, 1, 2), pch = c(1, 4, NA, NA), col = c("black", "red", "black", "red"), lwd = c(1, 1, 1.5, 1),
+       bty = "n", cex = 0.9, legend = c("Ben\u00e9z\u00e9th et al., 2007", "SUPCRTBL", "CHNOSZ", 'mod.obigt("dawsonite", Cp = 0)'))
+legend("topleft", c("Dawsonite solubility", "After Zimmer et al., 2016 Fig. 2"), bty = "n")
+reset()
 
 ###########
-### clean up: restore thermodynamic database to default
+### plot 3: kaolinite solubility
 ###########
+# After Tutolo et al., 2014, Fig. 2 (doi:10.1016/j.gca.2014.02.036)
+dat <- read.csv(system.file("extdata/cpetc/TKSS14_Fig2.csv", package = "CHNOSZ"))
+plot(dat, type = "p", xlim = c(3.5, 1.5), ylim = c(-2, 14), xlab = "1000/T(K)", ylab = "pK")
+# plot line: default database
+invTK <- seq(3.5, 1.6, -0.02)
+T <- 1000/invTK - 273.15
+sres <- subcrt(c("kaolinite", "OH-", "H2O", "Al(OH)4-", "H4SiO4"), c(-1, -2, -5, 2, 2), T = T)
+pK <- -sres$out$logK
+lines(invTK, pK, lwd = 1.5)
+# plot line: SUPCRT92
+add.obigt("SUPCRT92")
+sres <- subcrt(c("kaolinite", "OH-", "H2O", "Al(OH)4-", "H4SiO4"), c(-1, -2, -5, 2, 2), T = T)
+pK <- -sres$out$logK
+lines(invTK, pK, col = "blue", lty = 2)
+# add title and legend
+par(xpd = NA)
+title(main = describe.reaction(sres$reaction), cex.main = 1.1)
+par(xpd = FALSE)
+legend("topright", c("Kaolinite solubility", "After Tutolo et al., 2014 Fig. 2"), bty = "n")
+legend("bottomleft", lty = c(0, 2, 1), pch = c(1, NA, NA), lwd = c(1, 1, 1.5), col = c("black", "blue", "black"),
+       legend = c("Tutolo et al., 2014", "SUPCRT92", "CHNOSZ"), bty = "n", cex = 0.9)
 reset()
 
+###########
+### plot 4: albite - K-feldspar exchange
+###########
+# After Tutolo et al., 2014, Fig. 5 (doi:10.1016/j.gca.2014.02.036)
+# experimental data from Merino, 1975, Table 4 (doi:10.1016/0016-7037(75)90085-X)
+# plot line calculated using default database
+basis(c("Al2O3", "SiO2", "K+", "Na+", "O2", "H2O", "H+"))
+species(c("albite", "K-feldspar"))
+T <- 100
+P <- 150
+a <- affinity("K+" = c(4, 7), "Na+" = c(6, 9), T = T, P = P)
+diagram(a, lwd = 1.5, xlab = ratlab("K+"), ylab = ratlab("Na+"))
+# plot experimental data
+dat <- read.csv(system.file("extdata/cpetc/Mer75_Table4.csv", package = "CHNOSZ"))
+points(dat$log.aK..aH.., dat$log.aNa..aH..)
+# plot line calculated using SUPCRT92 data
+add.obigt("SUPCRT92")
+a <- affinity("K+" = c(4, 7), "Na+" = c(6, 9), T = 100, P = 150)
+diagram(a, col = "blue", lty = 2, add = TRUE, names = NULL)
+# add title and legend
+sres <- subcrt(c("albite", "K+", "K-feldspar", "Na+"), c(-1, -1, 1, 1))
+title(main = describe.reaction(sres$reaction), cex.main = 1.1)
+legend("topleft", c("Albite - K-feldspar", "After Tutolo et al., 2014 Fig. 5"), bty = "n", cex = 0.9)
+legend("bottomright", lty = c(0, 2, 1), pch = c(1, NA, NA), lwd = c(1, 1, 1.5), col = c("black", "blue", "black"),
+       legend = c("Merino, 1975", "SUPCRT92", "CHNOSZ"), bty = "n", cex = 0.9)
+legend("right", describe.property(c("T", "P"), c(T, P)), bty = "n")
+reset()
+
 par(opar)
@@ -1,48 +1,50 @@
-# CHNOSZ/demo/go-IU.R  20171018
-# diagrams using data from the SUPCRTBL compilation
-# (BL = Bloomington campus of Indiana University)
+# CHNOSZ/demo/go-IU.R 
+# 20171018 comparisons with calculations of SUPCRTBL
+#   (BL = Bloomington campus of Indiana University)
+# 20190415 add diagrams from Tutolo et al., 2014
 
 ## set up plotting area
@@ -53,34 +55,84 @@
 ### plot 2: dawsonite solubility
 ###########
-## experimental data from Benezeth et al., 2007 Table 5
-# doi:10.1016/j.gca.2007.07.003
+# After Zimmer et al., 2016 (doi:10.1016/j.cageo.2016.02.013)
+# experimental data from Benezeth et al., 2007 Table 5 (doi:10.1016/j.gca.2007.07.003)
 # (averages for each temperature in a single run)
 T <- c(100.1, 100.1, 150.1, 100.1, 150.1, 99.8, 99.8, 200.7, 99.8, 50.1, 75.1, 100.3, 150.1)

Modified: pkg/CHNOSZ/inst/NEWS
===================================================================